/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "poker.h"

void pokerInit(poker_t *poker) {
  uint8_t x;

  // Load the main shader
  assetShaderLoad(&poker->shader,
    "shaders/textured.vert", "shaders/textured.frag"
  );

  // Initialize the render stuffs.
  pokerWorldInit(poker);
  pokerCardInit(poker);
  pokerPlayerInit(poker);

  // Reset the main game state. This does not init the round.
  poker->blindBig = POKER_BLIND_BIG_DEFAULT;
  poker->blindSmall = POKER_BLIND_SMALL_DEFAULT;
  poker->roundDealer = 0x00;

  for(x = 0; x < POKER_PLAYER_COUNT; x++) {
    poker->players[x].state = 0x00;
    poker->players[x].chips = POKER_PLAYER_CHIPS_DEFAULT;
  }

  // Hand over to the deal for the first time.
  pokerDealInit(poker);
}

void pokerUpdate(poker_t *poker, render_t *render) {
  // Game Logic

  // TEMP
  cameraPerspective(&poker->camera, 20,render->width/render->height,0.001,1000);
  pokerLookAtPlayer(&poker->camera, pokerPlayerGetSeatForPlayer(0x00));

  // Render Logic
  shaderUse(&poker->shader);
  shaderUseCamera(&poker->shader, &poker->camera);

  pokerWorldRender(poker);
  for(uint8_t pi = 0; pi < POKER_PLAYER_COUNT; pi++) {
    uint8_t seat = pokerPlayerGetSeatForPlayer(pi);
    pokerPlayerRender(poker, poker->players + pi, seat);
  }
}

void pokerDispose(poker_t * poker) {
  pokerWorldDispose(poker);
  shaderDispose(&poker->shader);
}